/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */

/* Authors: Jaka Mocnik  <jaka.mocnik@kiss.uni-lj.si>
 */

#ifndef __PREFS_H__
#define __PREFS_H__

#include <gtk/gtkwidget.h>

#include "gtkgs.h"

extern gchar *gs_cmd;
extern gchar *gs_scan_pdf_cmd;
extern gchar *gs_uncompress_cmd;
extern gchar *gs_print_cmd;

extern gint gs_def_media;
extern gboolean gs_antialiased, gs_override_media;
extern gboolean gs_panel, gs_menubar;
extern gint gs_num_recent;

void load_prefs(gchar *);
void save_prefs(gchar *);
void set_prefs (GtkGS *);

#ifndef MAX_RECENT
#define MAX_RECENT 6
#endif



#endif
